@@ -10,7 +10,7 @@ from oss2 import Auth
 from lang.io import Properties
 
 __title__ = 'py-cli'
-__version__ = '1.2.3'
+__version__ = '1.2.4'
 
 __PYCLI_PATH = path.abspath(path.join(path.dirname(os.getcwd()), '.'))
 __LIBS_PATH = path.join(__PYCLI_PATH, 'libs')
@@ -65,12 +65,7 @@ class ArgOpts(object):
                     self.output_path = arg
 
         if len(self.project_path) <= 0:
-            cwd_path = os.getcwd()
-            if path.exists(path.join(cwd_path, self.app_module, 'build.gradle')):
-                project_path = cwd_path
-
-            else:
-                raise RuntimeError('\n[ERROR]: 当前目录非Android工程目录，请指定编译目录！！！')
+            self.project_path = os.getcwd()
 
         if not self.app_module:
             self.app_module = 'app'
@@ -78,6 +73,17 @@ class ArgOpts(object):
         if not self.output_path:
             self.output_path = os.getcwd()
 
+    def __str__(self):
+        return """--------------------------------------
+[INFO]:
+  operate         = %s
+  project_path    = %s
+  app_module      = %s
+  output_path     = %s
+  channel_config  = %s
+--------------------------------------
+""" % (self.operate, self.project_path, self.app_module, self.output_path, self.channel_config_path)
+
 
 class PyCliConfig(object):
     """
