@@ -20,6 +20,10 @@ def check_channel_config(channel_abspath):
     return path.exists(channel_abspath) and path.getsize(channel_abspath)
 
 
+def check_project(args: ArgOpts):
+    return path.exists(path.join(args.project_path, args.app_module, 'build.gradle'))
+
+
 def deploy(args: ArgOpts):
     module_abspath = path.join(args.project_path, args.app_module)
     if path.exists(module_abspath):
@@ -70,8 +74,14 @@ def deploy(args: ArgOpts):
 
 def main():
     args = ArgOpts()
+    print(args)
+
     if args.operate == OPT_DEPLOY:
-        deploy(args)
+        if check_project(args):
+            deploy(args)
+
+        else:
+            raise RuntimeError('\n[ERROR]: 当前目录非Android工程目录，请指定编译目录！！！')
 
 
 if __name__ == "__main__":
